@@ -46,7 +46,7 @@ from pytrainer.heartrategraph import HeartRateGraph
 from pytrainer.gui.drawGraph import DrawGraph
 from pytrainer.gui.windowcalendar import WindowCalendar
 from pytrainer.lib.listview import ListSearch
-from pytrainer.lib.uc import UC
+from pytrainer.lib import uc
 from pytrainer.core.activity import Activity
 from pytrainer.lib.localization import gtk_str
 from sqlalchemy import and_
@@ -59,7 +59,7 @@ class Main(SimpleBuilderApp):
         self.parent = parent
         self.pytrainer_main = parent
         self.data_path = data_path
-        self.uc = UC()
+        self.uc = uc.UC()
         SimpleBuilderApp.__init__(self, "pytrainer.ui")
 
         self.popup = PopupMenu(data_path,self)
@@ -106,7 +106,9 @@ class Main(SimpleBuilderApp):
                     {'name':_("Sport")},
                     {'name':_("Time"), 'xalign':1.0, 'format_duration':True},
                     {'name':_(u"\u2300 HR"), 'xalign':1.0},
+                    {'name':_("Max HR"), 'xalign':1.0},
                     {'name':_(u"\u2300 Speed"), 'xalign':1.0, 'format_float':'%.1f', 'quantity': 'speed'},
+                    {'name':_(u"\u2300 Pace"), 'xalign':1.0, 'format_pace':True},
                     {'name':_("Calories"), 'xalign':1.0}
                 ]
         self.create_treeview(self.allRecordTreeView,columns)
@@ -118,7 +120,7 @@ class Main(SimpleBuilderApp):
         columns=[   {'name':_("id"), 'visible':False},
                     {'name':_("Date")},
                     {'name':_("Weight"), 'xalign':1.0, 'quantity':'weight', 'format_float':'%.1f'},
-                    {'name':_("Body Fat %"), 'xalign':1.0},
+                    {'name':_("Body Fat %"), 'xalign':1.0, 'quantity':'none', 'format_float':'%.1f'},
                     {'name':_("Resting HR"), 'xalign':1.0},
                     {'name':_("Max HR"), 'xalign':1.0}
                 ]
@@ -129,8 +131,8 @@ class Main(SimpleBuilderApp):
                     {'name':_("Records"), 'xalign':1.0},
                     {'name':_("Total duration"), 'xalign':1.0, 'format_duration':True},
                     {'name':_("Total distance"), 'xalign':1.0, 'format_float':'%.1f', 'quantity':'distance'},
-                    {'name':_("Avg speed"), 'format_float':'%.2f', 'quantity':'maxspeed', 'xalign':1.0},
-                    {'name':_("Max speed"), 'format_float':'%.2f', 'quantity':'maxspeed', 'xalign':1.0},
+                    {'name':_("Avg speed"), 'format_float':'%.2f', 'quantity':'speed', 'xalign':1.0},
+                    {'name':_("Max speed"), 'format_float':'%.2f', 'quantity':'speed', 'xalign':1.0},
                     {'name':_("Avg HR"), 'xalign':1.0},
                     {'name':_("Max HR"), 'xalign':1.0},
                     {'name':_("Max duration"), 'xalign':1.0, 'format_duration':True},
@@ -221,6 +223,8 @@ class Main(SimpleBuilderApp):
         savedOptions.append(("id_record","False"))
         savedOptions.append(("time","False"))
         savedOptions.append(("beats","False"))
+        savedOptions.append(("maxbeats","False"))
+        savedOptions.append(("pace","False"))
         savedOptions.append(("calories","False"))
         menufile.createXMLFile("listviewmenu",savedOptions)
 
@@ -323,6 +327,11 @@ class Main(SimpleBuilderApp):
         _val_str = _format % float(_val)
         cell.set_property('text', _val_str)
 
+    def render_pace(self, column, cell, model, iter, idx):
+        _val = model.get_value(iter, idx)
+        _pace_str = uc.float2pace(self.uc.pace(uc.pace_from_db(_val)))
+        cell.set_property('text', _pace_str)
+
     def create_treeview(self,treeview,columns,sortable=True):
         for column_index, column_dict in enumerate(columns):
             if 'pixbuf' in column_dict:
@@ -335,8 +344,8 @@ class Main(SimpleBuilderApp):
                 column.add_attribute(renderer, 'pixbuf', column_index)
             else:
                 column.add_attribute(renderer, 'text', column_index)
-            column.set_resizable(True)
             column.set_sizing(Gtk.TreeViewColumnSizing.AUTOSIZE)
+            column.set_resizable(True)
             if 'xalign' in column_dict:
                 renderer.set_property('xalign', column_dict['xalign'])
             if 'visible' in column_dict:
@@ -345,6 +354,8 @@ class Main(SimpleBuilderApp):
                 column.set_cell_data_func(renderer, self.render_float, [column_dict['format_float'], column_dict['quantity'], column_index])
             if 'format_duration' in column_dict and column_dict['format_duration']:
                 column.set_cell_data_func(renderer, self.render_duration)
+            if 'format_pace' in column_dict:
+                column.set_cell_data_func(renderer, self.render_pace, column_index)
             if sortable:
                 column.set_sort_column_id(column_index)
             treeview.append_column(column)
@@ -1123,8 +1134,8 @@ class Main(SimpleBuilderApp):
 
     def actualize_statsview(self, stats, record_list):
         logging.debug(">>")
-        self.labelTotalDistance.set_text(str(stats.data['total_distance']) + " km")
-        self.labelTotalDuration.set_text(str(stats.data['total_duration'] / 3600) + " hours")
+        self.labelTotalDistance.set_text(str(round(stats.data['total_distance'])) + " km")
+        self.labelTotalDuration.set_text(str(round(stats.data['total_duration'] / 3600)) + " hours")
         # skip date format if no stats are saved yet
         try:
             self.labelStartDate.set_text(stats.data['start_date'].strftime('%Y-%m-%d'))
@@ -1185,6 +1196,8 @@ class Main(SimpleBuilderApp):
             GObject.TYPE_STRING,
             GObject.TYPE_STRING,
             GObject.TYPE_INT,
+            GObject.TYPE_INT,
+            GObject.TYPE_FLOAT,
             GObject.TYPE_FLOAT,
             GObject.TYPE_INT,
             object)
@@ -1197,8 +1210,7 @@ class Main(SimpleBuilderApp):
             try:
                 _id = i.id
             except (ValueError, TypeError) as e:
-                logging.debug("Unable to determine id for record: %s", i)
-                logging.debug(str(e))
+                logging.debug("Unable to determine id for record: %s. Exception: %s", i, e)
                 continue
             _title = i.title
             _date = str(i.date)
@@ -1211,6 +1223,10 @@ class Main(SimpleBuilderApp):
                 _average = i.average
             except (ValueError, TypeError):
                 _average = 0
+            try:
+                _pace = i.pace
+            except (ValueError, TypeError):
+                _pace = None
             try:
                 _calories = i.calories
             except (ValueError, TypeError):
@@ -1218,9 +1234,13 @@ class Main(SimpleBuilderApp):
             try:
                 _beats = round(i.beats)
             except (ValueError, TypeError) as e:
-                logging.debug("Unable to parse beats for %s", i.beats)
-                logging.debug(str(e))
+                logging.debug("Unable to parse beats for record: %s. Exception: %s", i.id, e)
                 _beats = 0.0
+            try:
+                _maxbeats = round(i.maxbeats)
+            except (ValueError, TypeError) as e:
+                logging.debug("Unable to parse maxbeats for record: %s. Exception: %s", i.id, e)
+                _maxbeats = 0.0
 
             iter = store.append()
             store.set (
@@ -1232,8 +1252,10 @@ class Main(SimpleBuilderApp):
                 4, _sport,
                 5, _time,
                 6, _beats,
-                7, _average,
-                8, _calories
+                7, _maxbeats,
+                8, _average,
+                9, _pace,
+                10, _calories
                 )
         #self.allRecordTreeView.set_headers_clickable(True)
         self.allRecordTreeView.set_model(store)
@@ -1325,7 +1347,9 @@ class Main(SimpleBuilderApp):
             _("Sport"):"sport",
             _("Time"):"time",
             _("Beats"):"beats",
+            _("Maxbeats"):"maxbeats",
             _("Average"):"average",
+            _("Pace"):"pace",
             _("Calories"):"calories"
             }
         self.listsearch.title = gtk_str(self.lsa_searchvalue.get_text())
@@ -1358,8 +1382,10 @@ class Main(SimpleBuilderApp):
             3:"sport",
             4:"time",
             5:"beats",
-            6:"average",
-            7:"calories" }
+            6:"maxbeats",
+            7:"average",
+            8:"pace",
+            9:"calories" }
 
         items = self.menulistviewOptions.get_children()
         if items[widget_position-1].get_active():
@@ -1380,8 +1406,10 @@ class Main(SimpleBuilderApp):
             "sport":4,
             "time":5,
             "beats":6,
-            "average":7,
-            "calories":8 }
+            "maxbeats":7,
+            "average":8,
+            "pace":9,
+            "calories":10 }
         columns = self.allRecordTreeView.get_columns()
         menuItems = self.menulistviewOptions.get_children()
         for column in listMenus:
@@ -1809,7 +1837,7 @@ class Main(SimpleBuilderApp):
                     date = self.parent.date.getDate()
                 except:
                     date = None
-                self.popup.show(selected.get_value(iter,0), event.button, time, date)
+                self.popup.show(selected.get_value(iter,0), event.button, time, str(date))
             elif event.button == 1:
                 self.notebook.set_current_page(0)
                 self.parent.refreshGraphView("record")
