@@ -1,14 +1,12 @@
-#!/usr/bin/env python
 import os, stat, sys
 import logging
 
 import random, re, urllib2, zipfile
 from math import floor, ceil
-from cStringIO import StringIO
 from osgeo import gdal, gdalnumeric
 
 from pytrainer.lib.srtmtiff import SrtmTiff
-import srtmdownload
+from . import srtmdownload
 
 class SrtmLayer(object):
     """
@@ -51,7 +49,7 @@ class SrtmLayer(object):
                 if not result:
                     return False
             else:
-                print "File already downloaded (%s)" % srtm_filename
+                logging.info("File already downloaded (%s)", srtm_filename)
                             
             self._cache[srtm_filename] = SrtmTiff(srtm_path)
         
