@@ -1,4 +1,4 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 
 #Copyright (C) Fiz Vazquez vud1@sindominio.net
 # Modified by dgranda
@@ -19,12 +19,13 @@
 
 import os, stat
 import logging
-from StringIO import StringIO
+from io import BytesIO
+from gettext import gettext as _
 
 from lxml import etree
-from environment import Environment
+from .environment import Environment
 from pytrainer.lib.singleton import Singleton
-from lib.uc import UC
+from .lib.uc import UC
 
 class Profile(Singleton):
     def __init__(self):
@@ -36,7 +37,7 @@ class Profile(Singleton):
         #Profile Options and Defaults
         self.profile_options = {
             "prf_name":"default",
-            "prf_gender":"",
+            "prf_gender":"Male",
             "prf_weight":"",
             "prf_height":"",
             "prf_age":"",
@@ -93,10 +94,26 @@ class Profile(Singleton):
     def plugindir(self):
         return self.environment.plugin_dir
 
+    @property
+    def sqlalchemy_url(self):
+        ddbb_type = self.getValue("pytraining","prf_ddbb")
+        ddbb_host = self.getValue("pytraining","prf_ddbbhost")
+        ddbb = self.getValue("pytraining","prf_ddbbname")
+        ddbb_user = self.getValue("pytraining","prf_ddbbuser")
+        ddbb_pass = self.getValue("pytraining","prf_ddbbpass")
+        if ddbb_type == "sqlite":
+            return "sqlite:///%s/pytrainer.ddbb" % self.confdir
+        else:
+            return "{type}://{user}:{passwd}@{host}/{db}".format(type=ddbb_type,
+                                                                 user=ddbb_user,
+                                                                 passwd=ddbb_pass,
+                                                                 host=ddbb_host,
+                                                                 db=ddbb)
+
     def refreshConfiguration(self):
         logging.debug(">>")
         self.configuration = self._parse_config_file(self.config_file)
-        logging.debug("Configuration retrieved: %s", str(self.configuration))
+        logging.debug("Configuration retrieved: %s", self.configuration)
         self.uc.set_us(self.prf_us_system)
         self._setZones()
         logging.debug("<<")
@@ -188,6 +205,7 @@ class Profile(Singleton):
                 config_needs_update = True
                 value = default
             config[key] = value
+        config_needs_update |= self.fixLocalizedGender(config)
         #Added a property, so update config
         if config_needs_update:
             self.setProfile(config)
@@ -195,6 +213,25 @@ class Profile(Singleton):
         self.prf_us_system = True if config["prf_us_system"] == "True" else False
         return config
 
+    @staticmethod
+    def fixLocalizedGender(config):
+        ''' The gender used to be stored as the
+            localized string. This fixes it.
+        '''
+        female_localized = ("Weiblich", "Mujer", "Femme", "Muller", "Feminino", "Kvinna")
+        male_localized = (u"Männlich", u"Varón", "Homme", "Home", "Masculino", u"Значение", "Man")
+        lgender = config["prf_gender"]
+        if lgender in ("Male", "Female"):
+            return False
+        elif lgender in female_localized:
+            config["prf_gender"] = "Female"
+        elif lgender in male_localized:
+            config["prf_gender"] = "Male"
+        else:
+            # default to not selected
+            config["prf_gender"] = ""
+        return True
+
     def getIntValue(self, tag, variable, default=0):
         ''' Function to return conf value as int
             returns
@@ -213,9 +250,9 @@ class Profile(Singleton):
 
     def getValue(self, tag, variable):
         if tag != "pytraining":
-            print "ERROR - pytraining is the only profile tag supported"
+            logging.critical("ERROR - pytraining is the only profile tag supported")
             return None
-        elif not self.configuration.has_key(variable):
+        elif variable not in self.configuration:
             return None
         return self.configuration[variable]
 
@@ -226,8 +263,8 @@ class Profile(Singleton):
         logging.debug("Setting %s to %s" % (variable, value))
         if self.xml_tree is None:
             #new config file....
-            self.xml_tree = etree.parse(StringIO('''<?xml version='1.0' encoding='UTF-8'?><pytraining />'''))
-        self.xml_tree.getroot().set(variable, value.decode('utf-8'))
+            self.xml_tree = etree.parse(BytesIO(b'''<?xml version='1.0' encoding='UTF-8'?><pytraining />'''))
+        self.xml_tree.getroot().set(variable, value)
         if not delay_write:
             self.saveProfile()
         logging.debug("<<")
@@ -235,7 +272,7 @@ class Profile(Singleton):
     def setProfile(self,list_options):
         logging.debug(">>")
         for option, value in list_options.items():
-            logging.debug("Adding "+option+"|"+value)
+            logging.debug("Adding %s|%s", option, value)
             self.setValue("pytraining",option,value,delay_write=True)
         self.uc.set_us(list_options['prf_us_system'])
         logging.debug("<<")
