@@ -16,27 +16,28 @@
 
 import unittest
 from datetime import date
-from mock import Mock
+try:
+    from unittest.mock import Mock
+except ImportError:
+    from mock import Mock
 
 from pytrainer.lib.ddbb import DDBB
-from pytrainer.waypoint import Waypoint
+from pytrainer.waypoint import WaypointService
 
 class WaypointTest(unittest.TestCase):
 
     def setUp(self):
-        profile = Mock()
-        profile.getValue = Mock(return_value='memory')
-        self.ddbb = DDBB(profile)
+        self.ddbb = DDBB()
         main = Mock()
         main.ddbb = self.ddbb
         main.ddbb.connect()
         main.ddbb.create_tables(add_default=False)
-        self.waypoint = Waypoint(parent=main)
+        self.waypoint = WaypointService(parent=main)
 
     def tearDown(self):
         self.waypoint = None
         self.ddbb.disconnect()
-        self.ddbb = None
+        self.ddbb.drop_tables()
 
     def test_waypoint_add_and_get(self):
         data = (30.0, 20.0, None, u'Comment', None, u'Test', u'sym')
@@ -44,7 +45,7 @@ class WaypointTest(unittest.TestCase):
                                          name=data[5], comment=data[3],
                                          sym=data[6])
         data2 = self.waypoint.getwaypointInfo(dbid)
-        self.assertEquals(data, data2[0])
+        self.assertEqual(data, data2[0])
 
     def test_waypoint_update(self):
         data = (30.0, 20.0, None, u'Comment', None, u'Test', u'sym')
@@ -53,7 +54,7 @@ class WaypointTest(unittest.TestCase):
         self.waypoint.updateWaypoint(dbid, data[0], data[1], data[5], data[3],
                                      data[6])
         data2 = self.waypoint.getwaypointInfo(dbid)
-        self.assertEquals(data, data2[0])
+        self.assertEqual(data, data2[0])
 
     def test_waypoint_get_all(self):
         data = (30.0, 20.0, None, u'Comment', None, u'Test', u'sym')
@@ -62,7 +63,7 @@ class WaypointTest(unittest.TestCase):
                                          sym=data[6])
         dbid = self.waypoint.addWaypoint(lat=50, lon=60, name='Test2',
                                          comment='Comment 2', sym='sym2')
-        self.assertEquals(len(self.waypoint.getAllWaypoints()), 2)
+        self.assertEqual(len(self.waypoint.getAllWaypoints()), 2)
 
     def test_waypoint_remove(self):
         data = (30.0, 20.0, None, u'Comment', None, u'Test', u'sym')
@@ -72,4 +73,4 @@ class WaypointTest(unittest.TestCase):
         dbid = self.waypoint.addWaypoint(lat=50, lon=60, name='Test2',
                                          comment='Comment 2', sym='sym2')
         self.waypoint.removeWaypoint(dbid)
-        self.assertEquals(len(self.waypoint.getAllWaypoints()), 1)
+        self.assertEqual(len(self.waypoint.getAllWaypoints()), 1)
